@@ -1,9 +1,8 @@
-#!@PERL@
+@PERL@
 # fixwfwps: fix Word for windows PostScript for printing.
-
-# feed this into perl
-eval 'exec perl -S $0 "$@"'
-   if $running_under_some_shell;
+#
+# Copyright (C) Angus J. C. Duggan 1991-1995
+# See file LICENSE for details.
 
 $nesting = 0;
 while (<>) {
@@ -31,3 +30,4 @@ while (<>) {
       }
    }
 }
+@END@
